@@ -51,6 +51,7 @@ QHash<int, QByteArray> MediaPlayList::roleNames() const
     roles[static_cast<int>(ColumnsRoles::DatabaseIdRole)] = "databaseId";
     roles[static_cast<int>(ColumnsRoles::TitleRole)] = "title";
     roles[static_cast<int>(ColumnsRoles::StringDurationRole)] = "duration";
+    roles[static_cast<int>(ColumnsRoles::DurationRole)] = "durationInt";
     roles[static_cast<int>(ColumnsRoles::ArtistRole)] = "artist";
     roles[static_cast<int>(ColumnsRoles::AlbumArtistRole)] = "albumArtist";
     roles[static_cast<int>(ColumnsRoles::AlbumRole)] = "album";
@@ -101,6 +102,9 @@ QVariant MediaPlayList::data(const QModelIndex &index, int role) const
         case ColumnsRoles::ElementTypeRole:
             result = QVariant::fromValue(d->mData[index.row()].mEntryType);
             break;
+        case ColumnsRoles::DurationRole:
+            result = d->mTrackData[index.row()].duration();
+            break;
         case ColumnsRoles::StringDurationRole:
         {
             QTime trackDuration = d->mTrackData[index.row()][TrackDataType::key_type::DurationRole].toTime();
@@ -200,6 +204,9 @@ QVariant MediaPlayList::data(const QModelIndex &index, int role) const
                     d->mData[index.row()].mArtist.toString(),
                     QUrl(QStringLiteral("image://icon/error")).toString()}}.toJson();
             break;
+        case ColumnsRoles::ResourceRole:
+            result = d->mData[index.row()].mTrackUrl;
+            break;
 
         default:
             result = {};
@@ -221,10 +228,6 @@ bool MediaPlayList::setData(const QModelIndex &index, const QVariant &value, int
         return modelModified;
     }
 
-    if (role < ColumnsRoles::IsValidRole || role > ColumnsRoles::IsPlayingRole) {
-        return modelModified;
-    }
-
     auto convertedRole = static_cast<ColumnsRoles>(role);
 
     switch(convertedRole)
